summaryrefslogtreecommitdiff
path: root/libs/pbd
diff options
context:
space:
mode:
authorCarl Hetherington <carl@carlh.net>2011-05-23 22:12:45 +0000
committerCarl Hetherington <carl@carlh.net>2011-05-23 22:12:45 +0000
commitb6587ad160aec275004ea875846112b8d4724d3d (patch)
tree610f2937f6a7796cd7de8aeb947eff7a48867c8b /libs/pbd
parentf7dae62903ad034bf42683001f235b84bf3b37f4 (diff)
Assorted doxygen fixes; no functional changes.
git-svn-id: svn://localhost/ardour2/branches/3.0@9575 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'libs/pbd')
-rw-r--r--libs/pbd/file_manager.cc20
-rw-r--r--libs/pbd/pbd/file_manager.h4
-rw-r--r--libs/pbd/pbd/search_path.h2
-rw-r--r--libs/pbd/pbd/sequence_property.h4
-rw-r--r--libs/pbd/pbd/sndfile_manager.h2
-rw-r--r--libs/pbd/sndfile_manager.cc16
-rw-r--r--libs/pbd/stateful.cc2
7 files changed, 27 insertions, 23 deletions
diff --git a/libs/pbd/pbd/file_manager.h b/libs/pbd/pbd/file_manager.h
index 5d957eaa5a..01c9a8ee31 100644
--- a/libs/pbd/pbd/file_manager.h
+++ b/libs/pbd/pbd/file_manager.h
@@ -89,7 +89,7 @@ private:
class FdFileDescriptor : public FileDescriptor
{
public:
- FdFileDescriptor (std::string const &, bool, mode_t);
+ FdFileDescriptor (std::string const & file_name, bool writeable, mode_t mode);
~FdFileDescriptor ();
int allocate ();
@@ -110,7 +110,7 @@ private:
class StdioFileDescriptor : public FileDescriptor
{
public:
- StdioFileDescriptor (std::string const &, std::string const &);
+ StdioFileDescriptor (std::string const & file_name, std::string const & mode);
~StdioFileDescriptor ();
FILE* allocate ();
diff --git a/libs/pbd/pbd/search_path.h b/libs/pbd/pbd/search_path.h
index 1148384daa..de0eeeeb5a 100644
--- a/libs/pbd/pbd/search_path.h
+++ b/libs/pbd/pbd/search_path.h
@@ -68,7 +68,7 @@ public:
* Initialize SearchPath from a vector of paths that may or may
* not exist.
*
- * @param path A path.
+ * @param paths A vector of paths.
*/
SearchPath (const std::vector<PBD::sys::path>& paths);
diff --git a/libs/pbd/pbd/sequence_property.h b/libs/pbd/pbd/sequence_property.h
index e01611a96f..3aeb83ce4e 100644
--- a/libs/pbd/pbd/sequence_property.h
+++ b/libs/pbd/pbd/sequence_property.h
@@ -110,7 +110,7 @@ class SequenceProperty : public PropertyBase
/** Get a representation of one of our items as XML. The representation must be sufficient to
* restore the item's state later; an ID is ok if someone else is storing the item state,
- * otherwise it needs to be the full state. The supplied node is an <Add> or <Remove>
+ * otherwise it needs to be the full state. The supplied node is an \<Add\> or \<Remove\>
* which this method can either add properties or children to.
*/
virtual void get_content_as_xml (typename ChangeContainer::value_type, XMLNode &) const = 0;
@@ -211,7 +211,7 @@ class SequenceProperty : public PropertyBase
return p;
}
- /** Given an <Add> or <Remove> node as passed into get_content_to_xml, obtain an item */
+ /** Given an \<Add\> or \<Remove\> node as passed into get_content_to_xml, obtain an item */
virtual typename Container::value_type get_content_from_xml (XMLNode const & node) const = 0;
void clear_owned_changes () {
diff --git a/libs/pbd/pbd/sndfile_manager.h b/libs/pbd/pbd/sndfile_manager.h
index a73f8cfd44..8fd155111b 100644
--- a/libs/pbd/pbd/sndfile_manager.h
+++ b/libs/pbd/pbd/sndfile_manager.h
@@ -34,7 +34,7 @@ namespace PBD {
class SndFileDescriptor : public FileDescriptor
{
public:
- SndFileDescriptor (std::string const &, bool, SF_INFO *);
+ SndFileDescriptor (std::string const & file_name, bool writeable, SF_INFO* info);
~SndFileDescriptor ();
SNDFILE* allocate ();
diff --git a/libs/pbd/stateful.cc b/libs/pbd/stateful.cc
index e65eb8d070..4eb8434af2 100644
--- a/libs/pbd/stateful.cc
+++ b/libs/pbd/stateful.cc
@@ -178,7 +178,7 @@ Stateful::get_changes_as_properties (Command* cmd) const
}
/** Set our property values from an XML node.
- * Derived types can call this from ::set_state() (or elsewhere)
+ * Derived types can call this from set_state() (or elsewhere)
* to get basic property setting done.
* @return IDs of properties that were changed.
*/
diff --git a/libs/pbd/file_manager.cc b/libs/pbd/file_manager.cc
index 50f0f2b22d..21f005cd4f 100644
--- a/libs/pbd/file_manager.cc
+++ b/libs/pbd/file_manager.cc
@@ -193,13 +193,13 @@ FileDescriptor::release ()
/** @param n Filename.
* @param w true to open writeable, otherwise false.
* @param m Open mode for the file.
*/
-FdFileDescriptor::FdFileDescriptor (string const & n, bool w, mode_t m)
- : FileDescriptor (n, w)
+FdFileDescriptor::FdFileDescriptor (string const & file_name, bool writeable, mode_t mode)
+ : FileDescriptor (file_name, writeable)
, _fd (-1)
, _mode (m)
{
@@ -259,14 +259,14 @@ FileDescriptor::set_path (const string& p)
_path = p;
}
-/** @param n Filename.
- * @param w true to open writeable, otherwise false.
+/** @param file_name Filename.
+ * @param mode Mode to pass to fopen.
*/
-StdioFileDescriptor::StdioFileDescriptor (string const & n, std::string const & m)
- : FileDescriptor (n, false)
+StdioFileDescriptor::StdioFileDescriptor (string const & file_name, std::string const & mode)
+ : FileDescriptor (file_name, false)
, _file (0)
- , _mode (m)
+ , _mode (mode)
{
manager()->add (this);
}
@@ -193,13 +193,13 @@ FileDescriptor::release ()
-/** @param n Filename.
- * @param w true to open writeable, otherwise false.
- * @param m Open mode for the file.
+/** @param file_name Filename.
+ * @param writeable true to open writeable, otherwise false.
+ * @param mode Open mode for the file.
*/
diff --git a/libs/pbd/sndfile_manager.cc b/libs/pbd/sndfile_manager.cc
index 5f08e634d6..9838515682 100644
--- a/libs/pbd/sndfile_manager.cc
+++ b/libs/pbd/sndfile_manager.cc
@@ -17,6 +17,10 @@
*/
+/** @file libs/pbd/sndfile_manager.cc
+ * @brief A FileDescriptor for files opened using libsndfile.
+ */
+
#include <sys/time.h>
#include <sys/resource.h>
#include <sys/types.h>
@@ -31,15 +35,15 @@
using namespace std;
using namespace PBD;
/** @param n Filename.
* @param w true to open writeable, otherwise false.
* @param i SF_INFO for the file.
*/
-SndFileDescriptor::SndFileDescriptor (string const & n, bool w, SF_INFO* i)
- : FileDescriptor (n, w)
+SndFileDescriptor::SndFileDescriptor (string const & file_name, bool writeable, SF_INFO* info)
+ : FileDescriptor (file_name, writeable)
, _sndfile (0)
- , _info (i)
+ , _info (info)
{
manager()->add (this);
}
@@ -31,15 +35,15 @@
using namespace std;
using namespace PBD;
-/** @param n Filename.
- * @param w true to open writeable, otherwise false.
- * @param i SF_INFO for the file.
+/** @param file_name Filename.
+ * @param writeable true to open writeable, otherwise false.
+ * @param info SF_INFO for the file.
*/